@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-84141e47bacd6d58a3602089bcd93f6c
-key: yesod_IpfSvcAibCMKReDKtQ1Ils
+id: yesod-1.4.2-920710b39b065bda5684c54c5a6f5e49
+key: yesod_IxSnnVp0a4HGIxaJIvMRvu
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,22 +21,22 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-IpfSvcAibCMKReDKtQ1Ils
+hs-libraries: HSyesod-1.4.2-IxSnnVp0a4HGIxaJIvMRvu
 depends:
     aeson-0.10.0.0-b63a88a6e7bf231c11601ff561c0eb0d
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-b598557be4ce3598e270c7592be1f33c
     blaze-markup-0.7.0.3-adfaa12a6c8f95338d1eda4a379eb541
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.9.2-a9d70a79ac1de8086bc3715f90a5fbf4
+    conduit-extra-1.1.9.2-1bef4166ec3f53ae2e6d2e9011cd9cbe
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     fast-logger-2.4.1-3a82ef8da5665c7f13125a65809925c9
-    monad-control-1.0.0.4-d9c084378409c615b7e0fe184537afc4
-    monad-logger-0.3.17-29f999a7bdec431fd6dfdb96b5644fed
+    monad-control-1.0.0.4-fa18b603f1c859e06ea8fbebdf00a3e7
+    monad-logger-0.3.17-6bebcabc98fb90582d59aab2ac8cf400
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.0.1-09717ed0a84e1dbeffebbb54d604d271
-    shakespeare-2.0.7-e268f1cc14a95a3be71df3c31a935ae6
+    shakespeare-2.0.7-00dfbe294be5d21a7267aeab62f6403d
     streaming-commons-0.1.15-bfe5dd5a0dc219d23135213ca9f37753
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
     wai-3.2.0-a50c1f56084e726fac99a6d8758a9179
-    wai-extra-3.0.13.1-9bbc6345fdd3fbfd0cf134c3f054b669
+    wai-extra-3.0.13.1-1bc7c4095875bfb4df8293ce63574926
     wai-logger-2.2.4.1-529e83bc9ac8fd22414c4cbc982c9843
     warp-3.2.1-90add4f6b8b8590f7d734b50560a29dd
-    yaml-0.8.15.2-b37a7f905feea0d122117d21f2571ab4
-    yesod-auth-1.4.11-6c7fcefbf299bb2811e870ac2868e81c
-    yesod-core-1.4.18.1-bcd5e3bc3c3a5156fb2a778107a2e530
-    yesod-form-1.4.6-77ea38dbad23b467d153b98a0280bf78
-    yesod-persistent-1.4.0.3-bb62530e0bc232db53fd8c39926f6d67
+    yaml-0.8.15.3-35e7f7b998eff49fb5374e4dc80a0cb1
+    yesod-auth-1.4.11-997100edb3e04364a3e6730f77e6a38f
+    yesod-core-1.4.18.1-1427f09c60204e2c904ad1c11de4a4ba
+    yesod-form-1.4.6-46903ec6bcb029c9002a4483982ff868
+    yesod-persistent-1.4.0.3-6906742652c1a7fb4b32fa3f8904977c
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
